#
# spec file for package NetworkManager-fortisslvpn
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define base_ver 1.4
%define pppd_plugin_dir %(rpm -ql ppp | grep -m1 pppd/[0-9]*)

Name:           NetworkManager-fortisslvpn
Version:        1.4.0
Release:        5.4
Summary:        NetworkManager VPN plugin for Fortinet compatible SSLVPN
License:        GPL-2.0-or-later
Group:          Productivity/Networking/System
URL:            https://gitlab.gnome.org/GNOME/NetworkManager-fortisslvpn
Source0:        https://download.gnome.org/sources/%{name}/%{base_ver}/%{name}-%{version}.tar.xz
# PATCH-FIX-UPSTREAM
Patch0:         https://gitlab.gnome.org/GNOME/NetworkManager-fortisslvpn/-/commit/084ef529.patch

BuildRequires:  intltool >= 0.35
BuildRequires:  libtool
BuildRequires:  libxml2-tools
BuildRequires:  ppp-devel
BuildRequires:  pkgconfig(gio-unix-2.0) >= 2.32
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.4
BuildRequires:  pkgconfig(gtk4) >= 4.0
BuildRequires:  pkgconfig(libnm) >= 1.2.0
BuildRequires:  pkgconfig(libnma) >= 1.2.0
BuildRequires:  pkgconfig(libnma-gtk4) >= 1.8.33
BuildRequires:  pkgconfig(libsecret-1) >= 0.18

Requires:       NetworkManager
Requires:       openfortivpn >= 1.11.0
Supplements:    (NetworkManager and openfortivpn)
# the pppd plugin are strict on the version, see boo#1175106
# ppe is transient already required by NM directly, but we need
# the versioned dep here to ensure a rebuild in case of ppp
# version changes
%requires_eq    ppp

%description
This package contains software for integrating Fortinet compatible
SSLVPN server VPN capabilities with with NetworkManager.

%package -n NetworkManager-applet-fortisslvpn
Summary:        NMA files for the NetworkManager SSLVPN plugin
Group:          Productivity/Networking/System
Requires:       %{name} = %{version}
Supplements:    (%{name} and NetworkManager-applet)
Supplements:    (%{name} and gnome-control-center)
Provides:       %{name}-gnome = %{version}
Obsoletes:      %{name}-gnome

%description -n NetworkManager-applet-fortisslvpn
This package contains the NMA files for integrating
Fortinet-compatible SSLVPN server VPN capabilities with
NetworkManager.

%lang_package

%prep
%autosetup -p1

%build
autoreconf -fiv
%configure \
	--disable-static \
	--with-pppd-plugin-dir=%{pppd_plugin_dir} \
	--with-gtk4=yes \
	%{nil}
%make_build

%install
%make_install dbusservicedir=%{_datadir}/dbus-1/system.d
%find_lang %{name} %{?no_lang_C}
find %{buildroot} -type f -name "*.la" -delete -print

%files
%license COPYING
%doc AUTHORS ChangeLog README
%{_datadir}/dbus-1/system.d/nm-fortisslvpn-service.conf
%{_vpnservicedir}/nm-fortisslvpn-service.name
%{_libexecdir}/nm-fortisslvpn-service
%{_libexecdir}/nm-fortisslvpn-pinentry
%{_libdir}/NetworkManager/libnm-vpn-plugin-fortisslvpn.so
%{pppd_plugin_dir}/nm-fortisslvpn-pppd-plugin.so
%{_sharedstatedir}/NetworkManager-fortisslvpn

%files -n NetworkManager-applet-fortisslvpn
%{_libexecdir}/nm-fortisslvpn-auth-dialog
%{_libdir}/NetworkManager/libnm-vpn-plugin-fortisslvpn-editor.so
%{_libdir}/NetworkManager/libnm-gtk4-vpn-plugin-fortisslvpn-editor.so
%{_datadir}/appdata/network-manager-fortisslvpn.metainfo.xml

%files lang -f %{name}.lang

%changelog
* Thu Mar 28 2024 Jonathan Kang <songchuan.kang@suse.com>
- Add missing supplements(bsc#1220391):
  + NMA subpackage: Main package and gnome-control-center
* Fri Dec 22 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Add 084ef529.patch: Add support for compiling against pppd-2.5.0.
- Add libtool BuildRequires and call autoreconf, as above patch
  touches the build system.
* Thu Nov  2 2023 Callum Farmer <gmbr3@opensuse.org>
- Rename gnome subpackage to NetworkManager-applet-fortisslvpn
  to more accurately reflect its usage
- Add missing requires: NetworkManager
- Add missing supplements:
  - NM and openfortivpn
  - NMA subpackage: Main package and NMA
* Thu Jan 26 2023 Callum Farmer <gmbr3@opensuse.org>
- Move dbus-1 system.d file to /usr (bsc#1207585)
* Sat Mar 12 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.4.0:
  + Gtk4 version of the editor plugin is now available (for use
    with Control Center of GNOME 42 or later).
  + Add support for interactive connect (e.g. OTP via SMS).
  + Drop privileges in pppd if "nm-fortisslvpn" user exists.
  + Allow more than 100 routes.
  + Updated translations.
- Drop NetworkManager-fortisslvpn-fix-incompat-openfortivpn.patch:
  fixed upstream.
- Add pkgconfig(gtk4) and pkgconfig(libnma-gtk4) BuildRequires and
  pass --with-gtk4=yes to configure, build the gtk4 version.
- Add optional libxml2-tools BuildRequires, build runs
  xml-stripblanks preprocessing if available.
* Thu Aug 13 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Require the same version ppp at runtime as we had during build
  time. We got away with the missing Requires as NM itself requires
  ppp, so 'a version' was always installed at least. But we need to
  guarantee the version at runtime matches the one we built against
  (boo#1175106).
* Fri May  1 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Set the path for the VPN service name file correctly to
  %%_vpnservicedir (provided by macros.NetworkManager).
* Thu Mar 26 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Add NetworkManager-fortisslvpn-fix-incompat-openfortivpn.patch:
  Fix incompatibility with openfortivpn >= 1.11.0 (boo#1167694,
  glgo#GNOME/NetworkManager-fortisslvpn!13).
* Sun Oct 27 2019 cges30901@gmail.com
- Add openfortivpn to Requires
* Sat Mar 23 2019 Jan Engelhardt <jengelh@inai.de>
- Write style: do summaries without em dashes, and do descriptions
  without double prepositions ("with X with Y").
* Thu Mar 21 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.2.10:
  + Add support for specifying the realm.
  + libnm-glib compatibility (NetworkManager < 1.0) is disabled by
    default. It can be enabled by passing --with-libnm-glib to
    configure script. Nobody should need it by now. Users that
    still use this are encouraged to let us know before the
    libnm-glib support is removed for good.
  + The auth helper in external UI mode can now be run without a
    display server. Future nmcli version will utilize this for
    handling the secrets without a graphical desktop.
* Wed Sep 26 2018 bjorn.lie@gmail.com
- Initial packaging for openSUSE.
